@@ -28,7 +28,7 @@
 /* avoid conflicting definition; __STDC_VERSION__ is not defined with ports gcc */
 #if defined(__OpenBSD__) || (defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)
 #  include <stdint.h>
-#elif defined(__sun) && defined(__SVR4)
+#elif (defined(__sun) && defined(__SVR4)) || defined(__hpux)
 #  include <inttypes.h>
 #else
 typedef   signed char      int8_t;	/* 8-bit int */
